# Searchlix
## _powerful python pakage to search in text and websites_



## Features

- Find emails in text / Email validation
- Find emails in website page
- Find phone number in text / Phone number validation
- Find phone number in website page
- Pattern search in text
- Search for page name in website




## Installation

python 3.6+

```sh
pip install searchlix
```

## Functions

How you can use it.

| Features | Function |
| ------ | ------ |
| Find emails in text / Email validation | find_email(text) |
| Find emails in website page | extract_email_from_link(url) |
| Find phone number in text / Phone number validation | find_phone_number(text) |
| Find phone number in website page | extract_phone_from_link(url) |
| Pattern search in text | pattern_search(text, pattern) |
| Search for page name in website | extract_page_url(url, page_name) |

## Example




```sh
from searchlix import searchlix
```



## License

MIT